@@ -310,6 +310,7 @@ impl Options {
                 .clone()
                 .or(config.source_maps)
                 .unwrap_or(SourceMapsConfig::Bool(false)),
+            inline_sources_content: config.inline_sources_content,
             input_source_map: self.config.input_source_map.clone(),
             output_path: output_path.map(|v| v.to_path_buf()),
             source_file_name,
@@ -389,6 +390,7 @@ impl Default for Rc {
                 minify: false,
                 source_maps: None,
                 input_source_map: InputSourceMap::default(),
+                ..Default::default()
             },
             Config {
                 env: None,
@@ -410,6 +412,7 @@ impl Default for Rc {
                 minify: false,
                 source_maps: None,
                 input_source_map: InputSourceMap::default(),
+                ..Default::default()
             },
             Config {
                 env: None,
@@ -431,6 +434,7 @@ impl Default for Rc {
                 minify: false,
                 source_maps: None,
                 input_source_map: InputSourceMap::default(),
+                ..Default::default()
             },
         ])
     }
@@ -501,6 +505,9 @@ pub struct Config {
     /// Possible values are: `'inline'`, `true`, `false`.
     #[serde(default)]
     pub source_maps: Option<SourceMapsConfig>,
+
+    #[serde(default)]
+    pub inline_sources_content: bool,
 }
 
 /// Second argument of `minify`.
@@ -539,6 +546,9 @@ pub struct JsMinifyOptions {
 
     #[serde(default)]
     pub output_path: Option<String>,
+
+    #[serde(default)]
+    pub inline_sources_content: bool,
 }
 
 /// `jsc.minify.format`.
@@ -649,7 +659,7 @@ impl Config {
     ///
     ///
     /// - typescript: `tsx` will be modified if file extension is `ts`.
-    fn adjust(&mut self, file: &Path) {
+    pub fn adjust(&mut self, file: &Path) {
         match &mut self.jsc.syntax {
             Some(Syntax::Typescript(TsConfig { tsx, .. })) => {
                 let is_ts = file.extension().map(|v| v == "ts").unwrap_or(false);
@@ -750,6 +760,8 @@ pub struct BuiltConfig<P: swc_ecma_visit::Fold> {
     pub source_file_name: Option<String>,
 
     pub preserve_comments: Option<BoolOrObject<JsMinifyCommentOption>>,
+
+    pub inline_sources_content: bool,
 }
 
 /// `jsc` in  `.swcrc`.
@@ -1058,6 +1070,8 @@ impl Merge for Config {
         self.minify.merge(&from.minify);
         self.env.merge(&from.env);
         self.source_maps.merge(&from.source_maps);
+        self.inline_sources_content
+            .merge(&from.inline_sources_content);
     }
 }
 
@@ -1071,6 +1085,7 @@ impl Merge for JsMinifyOptions {
         self.keep_fnames |= from.keep_fnames;
         self.safari10 |= from.safari10;
         self.toplevel |= from.toplevel;
+        self.inline_sources_content |= from.inline_sources_content;
     }
 }
 
